darkhistory.physics.coll_ion_xsec — DarkHistory documentation

# darkhistory.physics.coll_ion_xsec

`darkhistory.physics.` `coll_ion_xsec`(eng, species=None)

  e-e collisional ionization cross section in cm2.

  See 0906.1197.

  Parameters: | eng : float or ndarray Abscissa of kinetic energies. species : {‘HI’, ‘HeI’, ‘HeII’} Species of interest.
  Returns: | float or ndarray e-e collisional ionization cross section.

  Notes

  Returns the Arnaud and Rothenflug rate.

#### Previous topic

darkhistory.physics.coll_ion_sec_elec_spec

#### Next topic

darkhistory.physics.elec_heating_engloss_rate

### This Page

Show Source